# scbk_mlops

Local version of MLOps intended for limited capabilities (no DB connection) under network segregation

## Features

- 일반화된 데이터 Ingestion 단계
- 모형 뿐만 아닌 다양한 분석 과제에 활용 가능한 EDA 모듈
- Data 전처리 및 Engineering
- AI/ML 모형 학습
- AI/ML 모형 평가
- AI/ML 모형 모니터링

## Installation

```bash
pip install scbk_mlops
